@@ -101,7 +101,8 @@ def is_conditional(line):
         line.startswith(b'ifneq') or
         line.startswith(b'else') or
         line.startswith(b'endif') or
-        line.startswith(b'include'))
+        line.startswith(b'include') or
+        line.startswith(b'-include'))
 
 
 class Makefile(object):
@@ -127,12 +128,20 @@ class Makefile(object):
         mf = cls()
         keep = b''
         rule = None
+        joinedlines = []
         for line in contents.splitlines():
             line = keep + line
             keep = b''
             if line.endswith(b'\\'):
                 keep = line + b'\n'
                 continue
+            joinedlines.append(line)
+
+        if keep:
+            # file ends with continuation line..
+            joinedlines.append(keep)
+
+        for line in joinedlines:
             if line.startswith(b'\t') and rule:
                 rule.append_line(line)
             elif is_conditional(line) or line.startswith(b'#'):
@@ -155,9 +164,6 @@ class Makefile(object):
                 rule = None
                 mf.contents.append(line)
 
-        if keep:
-            raise ValueError('file ends with continuation line')
-
         if rule:
             mf.contents.append(rule)
 
