@@ -25,8 +25,10 @@ def test_suite():
         'control',
         'copyright',
         'deb822',
+        'debhelper',
         'dirty_tracker',
         'lintian_overrides',
+        'patches',
         'reformatting',
         'rules',
         'run',
