@@ -149,12 +149,12 @@ def guess_repo_from_url(url, net_access=False):
             return 'https://github.com/freedesktop/%s.git' % path_elements[2]
     if parsed_url.netloc == 'download.gnome.org':
         if len(path_elements) >= 2 and path_elements[0] == 'sources':
-            return 'https://gitlab.gnome.org/gnome/%s.git' % path_elements[1]
+            return 'https://gitlab.gnome.org/GNOME/%s.git' % path_elements[1]
     if parsed_url.netloc == 'ftp.gnome.org':
         if (len(path_elements) >= 4 and [
               e.lower() for e in path_elements[:3]] == [
                   'pub', 'gnome', 'sources']):
-            return 'https://gitlab.gnome.org/gnome/%s.git' % path_elements[3]
+            return 'https://gitlab.gnome.org/GNOME/%s.git' % path_elements[3]
     if parsed_url.netloc == 'sourceforge.net':
         if (len(path_elements) >= 4 and path_elements[0] == 'p'
                 and path_elements[3] == 'ci'):
@@ -742,6 +742,9 @@ def guess_upstream_metadata(
     extend_upstream_metadata(
         upstream_metadata, path, net_access=net_access,
         consult_external_directory=consult_external_directory)
+
+    fix_upstream_metadata(upstream_metadata)
+
     return {k: v.value for (k, v) in upstream_metadata.items()}
 
 
@@ -841,8 +844,8 @@ def guess_bug_database_url_from_repo_url(url):
 
 def bug_submit_url_from_bug_database_url(url):
     parsed_url = urlparse(url)
+    path_elements = parsed_url.path.strip('/').split('/')
     if parsed_url.netloc == 'github.com':
-        path_elements = parsed_url.path.strip('/').split('/')
         if len(path_elements) != 3:
             return None
         if path_elements[2] != 'issues':
@@ -851,10 +854,16 @@ def bug_submit_url_from_bug_database_url(url):
             ('https', 'github.com', parsed_url.path + '/new',
              None, None, None))
     if parsed_url.netloc == 'bugs.launchpad.net':
-        path_elements = parsed_url.path.strip('/').split('/')
         if len(path_elements) == 1:
             return urlunparse(
                 parsed_url._replace(path=parsed_url.path+'/+filebug'))
+    if parsed_url.netloc in KNOWN_GITLAB_SITES:
+        if len(path_elements) < 2:
+            return None
+        if path_elements[-1] != 'issues':
+            return None
+        return urlunparse(
+            parsed_url._replace(path=parsed_url.path.rstrip('/')+'/new'))
     return None
 
 
@@ -1011,6 +1020,71 @@ def check_upstream_metadata(upstream_metadata, version=None):
             bug_database.certainty = 'certain'
 
 
+def parse_pkgbuild_variables(f):
+    import shlex
+    variables = {}
+    keep = None
+    for line in f:
+        if (line.startswith(b'\t') or line.startswith(b' ') or
+                line.startswith(b'#')):
+            continue
+        if keep:
+            keep = (keep[0], keep[1] + line)
+            if line.rstrip().endswith(b')'):
+                variables[keep[0].decode()] = shlex.split(
+                    keep[1].rstrip(b'\n').decode())
+                keep = None
+            continue
+        try:
+            (key, value) = line.split(b'=', 1)
+        except ValueError:
+            continue
+        if value.startswith(b'('):
+            if value.rstrip().endswith(b')'):
+                value = value.rstrip()[1:-1]
+            else:
+                keep = (key, value[1:])
+                continue
+        variables[key.decode()] = shlex.split(value.rstrip(b'\n').decode())
+    return variables
+
+
+def guess_from_aur(package):
+    url = (
+        'https://aur.archlinux.org/cgit/aur.git/plain/PKGBUILD?h=%s-git' %
+        package)
+    headers = {'User-Agent': USER_AGENT}
+    try:
+        f = urlopen(
+            Request(url, headers=headers),
+            timeout=DEFAULT_URLLIB_TIMEOUT)
+    except urllib.error.HTTPError as e:
+        if e.status != 404:
+            raise
+        return
+
+    variables = parse_pkgbuild_variables(f)
+    for key, value in variables.items():
+        if key == 'url':
+            yield 'Homepage', value[0]
+        if key == 'source':
+            if not value:
+                continue
+            value = value[0]
+            if "${" in value:
+                for k, v in variables.items():
+                    value = value.replace('${%s}' % k, ' '.join(v))
+                    value = value.replace('$%s' % k, ' '.join(v))
+            try:
+                unique_name, url = value.split('::', 1)
+            except ValueError:
+                url = value
+            if url.startswith('git+'):
+                yield 'Repository', sanitize_vcs_url(url)
+        if key == '_gitroot':
+            yield 'Repository', sanitize_vcs_url(value[0])
+
+
 def guess_from_launchpad(package, distribution=None, suite=None):
     if distribution is None:
         # Default to Ubuntu; it's got more fields populated.
@@ -1062,7 +1136,12 @@ def guess_from_launchpad(package, distribution=None, suite=None):
                 if e.status != 404:
                     raise
                 if project_data['official_codehosting']:
-                    branch_data = _load_json_url(branch_link)
+                    try:
+                        branch_data = _load_json_url(branch_link)
+                    except urllib.error.HTTPError as e:
+                        if e.status != 404:
+                            raise
+                        branch_data = None
                     if branch_data:
                         yield 'Archive', 'launchpad'
                         yield 'Repository', branch_data['bzr_identity']
@@ -1089,6 +1168,15 @@ def guess_from_launchpad(package, distribution=None, suite=None):
         raise AssertionError('unknown vcs: %r' % project_data['vcs'])
 
 
+def fix_upstream_metadata(upstream_metadata):
+    """Fix existing upstream metadata."""
+    if 'Repository' in upstream_metadata:
+        repo = upstream_metadata['Repository']
+        url = repo.value
+        url = sanitize_vcs_url(url)
+        repo.value = url
+
+
 if __name__ == '__main__':
     import argparse
     import sys
