@@ -31,7 +31,12 @@ import re
 from urllib.parse import urlparse, urlunparse
 
 
-KNOWN_GITLAB_SITES = ['gitlab.com', 'salsa.debian.org', 'gitlab.gnome.org']
+KNOWN_GITLAB_SITES = [
+    'gitlab.com',
+    'salsa.debian.org',
+    'gitlab.gnome.org',
+    'gitlab.freedesktop.org',
+    ]
 
 
 def extract_vcs_url_branch(url):
@@ -144,6 +149,15 @@ def fix_branch_argument(parsed, branch):
     return None, None
 
 
+def fix_git_gnome_org_url(parsed, branch):
+    if parsed.netloc == 'git.gnome.org':
+        parsed = parsed._replace(
+            netloc='gitlab.gnome.org', scheme='https',
+            path='/GNOME' + parsed.path)
+        return parsed, branch
+    return None, None
+
+
 def fixup_broken_git_url(url):
     """Attempt to fix up broken Git URLs.
 
@@ -155,7 +169,7 @@ def fixup_broken_git_url(url):
     changed = False
     for fn in [fix_path_in_port, fix_salsa_scheme, fix_salsa_cgit_url,
                fix_salsa_tree_in_url, fix_double_slash, fix_extra_colon,
-               drop_git_username, fix_branch_argument]:
+               drop_git_username, fix_branch_argument, fix_git_gnome_org_url]:
         newparsed, newbranch = fn(parsed, branch)
         if newparsed:
             changed = True
